@@ -1,4 +1,4 @@
-# Copyright (c) 2008-2010, Michigan State University
+# Copyright (c) 2008, Michigan State University.
 
 """
 screed is a database tool useful for retrieving arbitrary kinds of sequence
@@ -24,11 +24,11 @@ ToFasta functions
 
 from __future__ import absolute_import
 
-from screed.openscreed import ScreedDB, open_writer
-from screed.openscreed import open_reader as open
+from screed.openscreed import ScreedDB
+from screed.openscreed import Open as open
 from screed.conversion import ToFastq
 from screed.conversion import ToFasta
-from screed.createscreed import create_db
+from screed.createscreed import create_db, make_db
 from screed.seqparse import read_fastq_sequences
 from screed.seqparse import read_fasta_sequences
 from screed.dna import rc
@@ -37,3 +37,7 @@ from screed.screedRecord import Record
 from screed._version import get_versions
 __version__ = get_versions()['version']
 del get_versions
+
+from ._version import get_versions
+__version__ = get_versions()['version']
+del get_versions
