@@ -1,4 +1,4 @@
-# Copyright (c) 2008-2015, Michigan State University
+# Copyright (c) 2008, Michigan State University.
 """Reader and writer for screed."""
 
 from __future__ import absolute_import
@@ -6,7 +6,6 @@ from __future__ import absolute_import
 import os
 import io
 import sys
-import sqlite3
 import gzip
 import bz2file
 try:
@@ -15,26 +14,18 @@ except ImportError:
     import UserDict
     MutableMapping = UserDict.DictMixin
 
+try:
+    import sqlite3
+except ImportError:
+    pass
+
 from . import DBConstants
 from . import screedRecord
-from .fastq import fastq_iter, FASTQ_Writer
-from .fasta import fasta_iter, FASTA_Writer
+from .fastq import fastq_iter
+from .fasta import fasta_iter
 from .utils import to_str
 
 
-def get_writer_class(read_iter):
-    if read_iter.__name__ == 'fasta_iter':
-        return FASTA_Writer
-    elif read_iter.__name__ == 'fastq_iter':
-        return FASTQ_Writer
-
-
-def open_writer(inp_filename, outp_filename):
-    read_iter = open_reader(inp_filename)
-    klass = get_writer_class(read_iter)
-    return klass(outp_filename)
-
-
 def _normalize_filename(filename):
     """Map '-' to '/dev/stdin' to handle the usual shortcut."""
     if filename == '-':
@@ -122,11 +113,6 @@ class Open(object):
             self.sequencefile.close()
 
 
-_open = open
-open = Open
-open_reader = open
-
-
 class ScreedDB(MutableMapping):
 
     """
@@ -135,6 +121,12 @@ class ScreedDB(MutableMapping):
     """
 
     def __init__(self, filepath):
+        try:
+            sqlite3
+        except NameError:
+            raise Exception("error: sqlite3 is needed for this " +
+                            "functionality, but is not installed.")
+
         self._filepath = filepath
         self._db = None
         if not self._filepath.endswith(DBConstants.fileExtension):
@@ -165,7 +157,7 @@ class ScreedDB(MutableMapping):
                             % self._filepath)
 
         nothing = res.fetchone()
-        if type(nothing) is not type(None):
+        if nothing is not None:
             self._db.close()
             raise TypeError("Database %s has too many tables." % filename)
 
@@ -215,7 +207,7 @@ class ScreedDB(MutableMapping):
                                                   DBConstants._DICT_TABLE,
                                                   self._queryBy)
         res = cursor.execute(query, (key,))
-        if type(res.fetchone()) is type(None):
+        if res.fetchone() is None:
             raise KeyError("Key %s not found" % key)
         return screedRecord._buildRecord(self.fields, self._db,
                                          key,
@@ -244,7 +236,7 @@ class ScreedDB(MutableMapping):
                                                   DBConstants._DICT_TABLE,
                                                   DBConstants._PRIMARY_KEY)
         res = cursor.execute(query, (index,))
-        if type(res.fetchone()) is type(None):
+        if res.fetchone() is None:
             raise KeyError("Index %d not found" % index)
         return screedRecord._buildRecord(self.fields, self._db,
                                          index,
