@@ -1,8 +1,12 @@
+# Copyright (c) 2016, The Regents of the University of California.
+
 from __future__ import absolute_import
+from functools import total_ordering
 import types
 from . import DBConstants
 import gzip
 import bz2
+from io import BytesIO
 
 try:
     from collections import MutableMapping
@@ -16,8 +20,18 @@ class Record(MutableMapping):
     Simple dict-like record interface with bag behavior.
     """
 
-    def __init__(self, *args, **kwargs):
-        self.d = dict(*args, **kwargs)
+    def __init__(self, name=None, sequence=None, **kwargs):
+        d = dict()
+        if name is not None:
+            d['name'] = name
+        if sequence is not None:
+            d['sequence'] = sequence
+
+        d.update(kwargs)
+
+        if 'quality' in d and d['quality'] is None:
+            del d['quality']
+        self.d = d
 
     def __setitem__(self, name, value):
         self.d[name] = value
@@ -36,11 +50,11 @@ class Record(MutableMapping):
 
     def __getitem__(self, idx):
         if isinstance(idx, slice):
-            trimmed = Record(self.d)
+            trimmed = dict(self.d)
             trimmed['sequence'] = trimmed['sequence'][idx]
             if 'quality' in trimmed:
                 trimmed['quality'] = trimmed['quality'][idx]
-            return Record(trimmed)
+            return Record(**trimmed)
         return self.d[idx]
 
     def __delitem__(self, key):
@@ -53,6 +67,7 @@ class Record(MutableMapping):
         return repr(self.d)
 
 
+@total_ordering
 class _screed_attr(object):
 
     """
@@ -108,46 +123,20 @@ class _screed_attr(object):
         """
         return "<%s '%s'>" % (self.__class__.__name__, self._attrName)
 
-    def __cmp__(self, given):
-        """
-        Handles comparisons other than == and !=
-        """
-        ownString = __str__()
-        if isinstance(given, _screed_attr):
-            given = str(given)
-        elif not isinstance(given, str):
-            raise TypeError("Cannot compare to given type: %s" % type(given))
-
-        if ownString < given:
-            return -1
-        elif ownString > given:
-            return 1
-        else:
-            return 0
-
     def __eq__(self, given):
         """
         Compares attribute to given object in string form
         """
         if isinstance(given, bytes):
             return given == self.__str__()
-
-        try:
+        else:
             return str(given) == self.__str__()
-        except AttributeError:
-            raise TypeError("Cannot compare to given type: %s" % type(given))
 
-    def __ne__(self, given):
-        """
-        Compares attribute to given object in string form
-        """
+    def __lt__(self, given):
         if isinstance(given, bytes):
-            return self.__repr__() != given
-
-        try:
-            return self.__repr__() != str(given)
-        except AttributeError:
-            raise TypeError("Cannot compare to given type: %s" % type(given))
+            return self.__str__() < given
+        else:
+            return self.__str__() < str(given)
 
     def __str__(self):
         """
@@ -201,26 +190,39 @@ def _buildRecord(fieldTuple, dbObj, rowName, queryBy):
         else:
             hackedResult.append((key, value))
 
-    return Record(hackedResult)
+    return Record(**dict(hackedResult))
 
 
-class _Writer(object):
+def write_fastx(record, fileobj):
+    """Write sequence record to 'fileobj' in FASTA/FASTQ format."""
+    isbytesio = isinstance(fileobj, BytesIO)
+    iswb = hasattr(fileobj, 'mode') and fileobj.mode == 'wb'
+    outputvalid = isbytesio or iswb
+    if not outputvalid:
+        message = ('cannot call "write_fastx" on object, must be of a file '
+                   'handle with mode "wb" or an instance of "BytesIO"')
+        raise AttributeError(message)
 
-    def __init__(self, filename, fp=None):
-        self.filename = filename
-        if fp is None:
-            if filename.endswith('.gz'):
-                fp = gzip.open(filename, 'w')
-            elif filename.endswith('.bz2'):
-                fp = bz2.BZ2File(filename, 'w')
-            else:
-                fp = file(filename, 'wb')
+    defline = record.name
+    if hasattr(record, 'description'):
+        defline += ' ' + record.description
 
-        self.fp = fp
+    if hasattr(record, 'quality'):
+        recstr = '@{defline}\n{sequence}\n+\n{quality}\n'.format(
+            defline=defline,
+            sequence=record.sequence,
+            quality=record.quality)
+    else:
+        recstr = '>{defline}\n{sequence}\n'.format(
+            defline=defline,
+            sequence=record.sequence)
 
-    def consume(self, read_iter):
-        for read in read_iter:
-            self.write(read)
+    fileobj.write(recstr.encode('utf-8'))
 
-    def close(self):
-        self.fp.close()
+
+def write_fastx_pair(read1, read2, fileobj):
+    """Write a pair of sequence records to 'fileobj' in FASTA/FASTQ format."""
+    if hasattr(read1, 'quality'):
+        assert hasattr(read2, 'quality')
+    write_record(read1, fileobj)
+    write_record(read2, fileobj)
